Coverage for airflow.hooks.sqlite_hook: 70%

# Coverage for airflow.hooks.sqlite_hook : 70%

## 10 statements 7 run 3 missing 0 excluded

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 | import sqlite3 from airflow.hooks.dbapi_hook import DbApiHook class SqliteHook(DbApiHook): """ Interact with SQLite. """ conn_name_attr = 'sqlite_conn_id' default_conn_name = 'sqlite_default' supports_autocommit = False def get_conn(self): """ Returns a sqlite connection object """ conn = self.get_connection(self.sqlite_conn_id) conn = sqlite3.connect(conn.host) return conn